<?php
/** Fichier cree le 4 mai 07 par quinton
 *
 *UTF-8
 *
 * Classe maîtrisant les aspects identification.
 */

/**
 * @class Identification
 * Gestion de l'identification - récupération du login en fonction du type d'accès
 * @author Eric Quinton - eric.quinton@free.fr
 *
 */

class Identification {
	var $ident_type = NULL;
	var $CAS_address ;
	var $CAS_port;
	var $LDAP_address;
	var $LDAP_port;
	var $LDAP_rdn;
	var $password;
	var $login;
	var $gacl;
	var $aco;
	var $aro;
	var $pagelogin;

	function setpageloginBDD($page) {
		$this->pagelogin = $page;
	}
	/**
	 * @param $ident_type string
	 */
	function setidenttype($ident_type){
		$this->ident_type = $ident_type;
	}
	/**
	 * initialisation si utilisation d'un CAS
	 * @param $cas_address adresse du CAS
	 * @param $CAS_port port du CAS
	 * @return  none
	 */
	function init_CAS($cas_address,$CAS_port) {
		$this->CAS_address = $cas_address;
		$this->CAS_port = $CAS_port;
		$this->ident_type = "CAS";

	}
	/**
	 * initialisation si utilisation d'un LDAP
	 * @param $LDAP_address adresse du CAS
	 * @param $LDAP_port port du serveur LDAP
	 * @param $LDAP_rdn chemin complet de recherche, incluant le login
	 * @param $login login qui sera retourné à l'application
	 * @param $password mot de passe à tester
	 * @return  none
	 */

	function init_LDAP($LDAP_address, $LDAP_port,$LDAP_rdn, $login, $password) {
		$this->LDAP_address = $LDAP_address;
		$this->LDAP_port = $LDAP_port;
		$this->LDAP_rdn = $LDAP_rdn;
		$this->ident_type = "LDAP";
		$this->login = $login;
		$this->password = $password;
	}

	/**
	 * Retourne le login selon le mode d'accès choisi
	 *
	 * @return login ou -1 - Le login est stocké en variable de session si ok
	 */
	function getLogin() {
		$ident_type = $this->ident_type;
		if (!isset($ident_type)){
			echo "Cette fonction doit être appelée après soit init_LDAP, init_CAS, ou init_BDD";
			die;
		}
		if (!isset($_SESSION["login"])) {
			/*
			 * Récupération du login selon le type
			 */
			if ($ident_type == "BDD") {

			}elseif ($ident_type == "CAS") {

				phpCAS::client(CAS_VERSION_2_0,$this->CAS_address,$this->CAS_port,'');
				if (phpCAS::isAuthenticated()==FALSE) {
					phpCAS::forceAuthentication();
				}
				$_SESSION["login"] = phpCAS::getUser();
			}elseif ($ident_type=="LDAP"){

				$ldap = ldap_connect($this->LDAP_address,$this->LDAP_port);
				$rs= ldap_bind($ldap, $this->LDAP_rdn, $this->password);
				if ($rs==1)
				{
					$_SESSION["login"] = $this->login;
				}
			}
		}

		if (isset( $_SESSION["login"])) {
			return $_SESSION["login"];
		}else{
			return -1;
		}


	}
	/**
	 * Déconnexion de l'application
	 * @return 0:1
	 */
	function disconnect() {
		if (!isset($this->ident_type)) {
			return 0;
		}
		if ($this->ident_type == "CAS") {
			phpCAS::logout("");
		}
		// Détruit toutes les variables de session
		$_SESSION = array();

		// Si vous voulez détruire complètement la session, effacez également
		// le cookie de session.
		// Note : cela détruira la session et pas seulement les données de session !
		if (isset($_COOKIE[session_name()])) {
			setcookie(session_name(), '', time()-42000, '/');
		}

		// Finalement, on détruit la session.
		session_destroy();
		return 1;

	}
	/**
	 * Initialisation de la classe gacl
	 * @param $gacl instance gacl
	 * @param $aco nom de la catégorie de base contenant les objets à tester
	 * @param $aro nom de la catégorie contenant les logins à tester
	 */
	function setgacl($gacl,$aco,$aro) {
		$this->gacl=$gacl;
		$this->aco=$aco;
		$this->aro=$aro;

	}
	/**
	 * Teste les droits
	 * @param $aco Catégorie à tester
	 * @return 0|1
	 */
	function getgacl($aco){
		$login = $this->getLogin();
		if ($login ==-1) return -1;
		return $this->gacl->acl_check($this->aco,$aco,$this->aro,$login);

	}
}

/**
 * Classe permettant de manipuler les logins stockés en base de données locale
 *
 */
class LoginGestion extends ObjetBDD
{
	//

	function LoginGestion($link)
	{
		$this->table="LoginGestion";
		ObjetBDD::ObjetBDD($link);
		$this->id_auto = 1;
		$this->types=array(
		'id'=>1);
	}
	function VerifLogin($login,$password){
		$password = md5($password);
		$sql='select login from LoginGestion where login ="'.$login
		.'" and password = "'.$password.'"';
		$res=ObjetBDD::lireParam($sql);
		if ($res["login"]==$login) {
			return TRUE;
		}else{
			return FALSE;
		}
	}
	function getListeTriee(){
		$sql = 'select id,login,nom,prenom,mail from LoginGestion order by nom,prenom';
		return ObjetBDD::getListeParam($sql);
	}
	function ecrire($liste){
		$list=array();
		$list[0]=$liste["id"];
		$list[1]=$liste["login"];
		if(isset($liste["pass1"])&&isset($liste["pass2"])&&$liste["pass1"]==$liste["pass2"]&&strlen($liste["pass1"])>3) {
			$list[2]=md5($liste["pass1"]);
		}else{
			$list[2]=$liste["password"];
		}
		$list[3]=$liste["nom"];
		$list[4]=$liste["prenom"];
		$list[5]=$liste["mail"];
		return ObjetBDD::ecrire($list);
	}
}
?>